# -*- coding: utf-8 -*-
"""Project python-bts

Information describing the project.
"""

# The package name, which is also the "UNIX name" for the project.
package = 'bts'
project = "python api for BitShares"
project_no_spaces = project.replace(' ', '')
version = '0.6.2'
description = 'api for BitShares'
authors = ['Alt']
authors_string = ', '.join(authors)
emails = ['pch957@gmail.com']
license = 'MIT'
copyright = '2015 ' + authors_string
url = 'https://github.com/pch957/python-bts'
